==> pam_flutter-1.3.7.tar.gz: test/pam_flutter_test.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:pam_flutter/mocks/pdpa/contacting_consent.dart';
import 'package:pam_flutter/models/consent_message_model.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/pdpa_repository.dart';

void main() {
  ConsentMessageModel? consentBuilder() {
    return ConsentMessageModel.fromJson(mockContactingConsentDetail);
  }

  test('pam url parser', () async {
    String url = "3dsflutter//products?id=1nxPka3SwRwOuqEq9IdD5mcu6Wu";
    Uri uri = Uri.parse(url);

    expect(uri.queryParameters["id"], "1nxPka3SwRwOuqEq9IdD5mcu6Wu");
  });

  test("Consent Model Test", () {
    ConsentMessageModel? data = consentBuilder();
    bool isAllowed = true;

    data?.Setting.TermsAndConditions.IsAllowed = false;
    expect(data?.Setting.TermsAndConditions.IsAllowed, false);
    data?.Setting.TermsAndConditions.IsAllowed = isAllowed;
    expect(data?.Setting.TermsAndConditions.IsAllowed, isAllowed);
  });

  testWidgets('adds one to input values', (WidgetTester tester) async {
    await tester.pumpWidget(
      Builder(
        builder: (BuildContext context) {
          PDPARepository pdpaRepository = PDPARepository(
            buildCtx: context,
            options: NewRepositoryOptions(
              baseUrl: "https://stg-mkt.pams.ai/api/pdpa/consent-message",
              findUrl: "https://stg-mkt.pams.ai/api/pdpa/consent-message/:id",
            ),
          );
          pdpaRepository.get("1q6T8Z5jISvcgEvusrAGnvfuxXY");

          return Container();
        },
      ),
    );
  });
}

==> pam_flutter-1.5.71.tar.gz: test/pam_flutter_test.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:pam_flutter/mocks/pdpa/contacting_consent.dart';
import 'package:pam_flutter/models/consent_message_model.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/pdpa_repository.dart';

void main() {
  ConsentMessageModel? consentBuilder() {
    return ConsentMessageModel.fromJson(mockContactingConsentDetail);
  }

  test('pam url parser', () async {
    String url = "3dsflutter//products?id=1nxPka3SwRwOuqEq9IdD5mcu6Wu";
    Uri uri = Uri.parse(url);

    expect(uri.queryParameters["id"], "1nxPka3SwRwOuqEq9IdD5mcu6Wu");
  });

  test("Consent Model Test", () {
    var data = consentBuilder();
    data!.Setting.TermsAndConditions.IsAllowed = false;
    print("Check before = ${data.Setting.TermsAndConditions.IsAllowed}");
    data.Setting.TermsAndConditions.IsAllowed = true;
    print("Check after = ${data.Setting.TermsAndConditions.IsAllowed}");
  });

  testWidgets('adds one to input values', (WidgetTester tester) async {
    await tester.pumpWidget(
      Builder(
        builder: (BuildContext context) {
          PDPARepository pdpaRepository = PDPARepository(
            buildCtx: context,
            options: NewRepositoryOptions(
              baseUrl: "https://stg-mkt.pams.ai/api/pdpa/consent-message",
              findUrl: "https://stg-mkt.pams.ai/api/pdpa/consent-message/:id",
            ),
          );
          pdpaRepository.get("1q6T8Z5jISvcgEvusrAGnvfuxXY");

          return Container();
        },
      ),
    );
  });
}
